@@ -17,7 +17,7 @@ import uuid
 import heapq
 import numpy as np
 
-from optparse import OptionParser
+import argparse
 from collections import namedtuple
 from multiprocessing import Process, Pool
 from matplotlib import pyplot
@@ -31,7 +31,6 @@ RESULT_DIR = 'results'
 PHRASE_GROUP = 0
 PHRASE_SORT = 1
 PHRASE_PROCESS = 2
-options = dict()
 
 def openFile(file):
   """
@@ -206,8 +205,8 @@ def groupDataByModel(inputDir):
   fileByModel = dict()
   for file in walktree(inputDir):
     for line in openFile(file):
-      fields = line.split(options.delimiter)
-      if options.ignoreInvalid:
+      fields = line.split(args.delimiter)
+      if args.ignoreInvalid:
         if len(fields) != 4 or fields[0] == '' or fields[1] == '' or fields[2] == '' or fields[3] == '':
           print('Ingonre Invalid line', fields)
           continue
@@ -220,13 +219,13 @@ def groupDataByModel(inputDir):
   t2 = time.time()
   print("merging files take %ss" % (t2 - t1))
 
-  if options.useMask:
+  if args.useMask:
     fileByModel = removeMaskData(fileByModel)
   return fileByModel
 
 def removeMaskData(dataByName):
   toRemoveList = []
-  masks = options.useMask.split(',')
+  masks = args.useMask.split(',')
   for mask in masks:
     for name in dataByName.keys():
       if mask.endswith('*'):
@@ -265,12 +264,12 @@ def sortDataFileByModel(fileByModel):
   for model in list(fileByModel.keys()):
     mergedFile = '%s/%s.txt' % (MERGE_DIR, model)
     sortedFile = '%s/%s.txt' % (SORT_DIR, model)
-    if options.ignoreInvalid:
-      key = eval('lambda l: -float(l.split("' + options.delimiter + '")[2] or 0.0)')
+    if args.ignoreInvalid:
+      key = eval('lambda l: -float(l.split("' + args.delimiter + '")[2] or 0.0)')
     else:
-      key = eval('lambda l: -float(l.split("' + options.delimiter + '")[2])')
+      key = eval('lambda l: -float(l.split("' + args.delimiter + '")[2])')
     process = Process(target = batchSort,
-      args=(mergedFile, sortedFile, key, options.bufferSize))
+      args=(mergedFile, sortedFile, key, args.bufferSize))
     process.start()
     processPool.append(process)
 
@@ -297,31 +296,31 @@ def processDataByModel(fileByModel):
       (model, data) = result.get()
       dataByModel[model] = data
     except Exception as e:
-      if not options.ignoreInvalid:
+      if not args.ignoreInvalid:
         raise e
   t2 = time.time()
 
-  if options.aucSelect:
-    selectLimit = options.selectLimit
+  if args.aucSelect:
+    selectLimit = args.selectLimit
     print('Sort model by AUC and select top', selectLimit)
     sortedModelTuple = sorted(list(dataByModel.items()), key=lambda item: item[1]['AUC'], reverse=True)
     dataByModel = dict(sortedModelTuple[:selectLimit])
 
-  if options.verbose:
+  if args.verbose:
     print(dataByModel)
   plotCurves(dataByModel)
   print("processing data take %ss" % (t2 - t1))
   
 def processData(model, input):
   """
-  Process data. Bin data into options.shardCount bins. Accumulate data for each bin and populate necessary metrics. 
+  Process data. Bin data into args.shardCount bins. Accumulate data for each bin and populate necessary metrics. 
   """
   print('processData data for %s' % model)
-  data = np.loadtxt(input, delimiter = options.delimiter,
+  data = np.loadtxt(input, delimiter = args.delimiter,
     dtype = {'names' : ('model', 'weight', 'score', 'label'),
              'formats' : ('S16', 'f4', 'f4', 'i1')}) 
   dataSize = len(data)
-  shardSize = old_div(dataSize, options.shardCount)
+  shardSize = old_div(dataSize, args.shardCount)
 
   rocPoints = [(0, 0)]
   prPoints = []
@@ -398,7 +397,7 @@ def processData(model, input):
   print('%s AUC: %f' % (model, AUC))
   print('%s F1: %f' % (model, F1))
   print('%s Observed/Expected Ratio: %f' % (model, OER))
-  if options.cutoff:
+  if args.cutoff:
     print('%s cutoff:' % model, cutoff)
 
   return model, { 'ROC': rocPoints, 'PR': prPoints, 'CORR': corrPoints, 'AUC': AUC, 'OER': OER, 'F1': F1, 'cutoff': cutoff}
@@ -406,15 +405,16 @@ def processData(model, input):
 def configChart():
   cf = pylab.gcf()
   defaultSize = cf.get_size_inches()
-  plotSizeXRate = options.plotSizeRate
-  plotSizeYRate = options.plotSizeRate
+  plotSizeXRate = args.plotSizeRate
+  plotSizeYRate = args.plotSizeRate
   cf.set_size_inches( (defaultSize[0]*plotSizeXRate, defaultSize[1]*plotSizeYRate) )
 
 
-def roc(inputDir, phrase):
+def roc():
+  phrase = args.phrase
   if phrase == PHRASE_GROUP:
-    fileByModel = groupDataByModel(inputDir)
-    if options.verbose:
+    fileByModel = groupDataByModel(args.inputDir)
+    if args.verbose:
       print(fileByModel)
     phrase = PHRASE_GROUP + 1
   else:
@@ -429,42 +429,39 @@ def roc(inputDir, phrase):
   processDataByModel(fileByModel)
 
 def main():
-  parser = OptionParser()
+  parser = argparse.ArgumentParser()
 
-  parser.add_option('-p', '--phrase', dest='phrase', default=0, type='int',
-    help='Start phrase. 0:Group, 1:Sort, 2:Process')
+  parser.add_argument('inputDir', help='Input format: CSV by --delimiter: len(rocord)==4. Ex: modelId, weight, score, label')
 
-  parser.add_option('-d', '--delimiter', dest='delimiter', default='\x01',
+  parser.add_argument('-p', '--phrase', dest='phrase', default=0, type=int,
+    help='Start phrase. 0 : Group, 1 : Sort,  2 : Process')
+
+  parser.add_argument('-d', '--delimiter', dest='delimiter', default='\x01',
     help='CSV field delimiter.')
 
-  parser.add_option('-s', '--shard', dest='shardCount', default=64, type='int',
+  parser.add_argument('-s', '--shard', dest='shardCount', default=64, type=int,
     help='Shard count. Specify how many data point to generate for plotting.')
 
-  parser.add_option('-b', '--buffer', dest='bufferSize', default=32000, type='int',
+  parser.add_argument('-b', '--buffer', dest='bufferSize', default=32000, type=int,
     help='bufferSize to use for sorting')
 
-  parser.add_option('-v', '--verbose', action='store_true', help='Be verbose')
+  parser.add_argument('-v', '--verbose', action='store_true', help='Be verbose')
 
-  parser.add_option('--cutoff', dest='cutoff', action='store_true', help='print cutoff')
+  parser.add_argument('--cutoff', dest='cutoff', action='store_true', help='print cutoff')
 
-  parser.add_option('-i', '--ignoreInvalid', action='store_true', help='Ignore invalid in thread')
+  parser.add_argument('-i', '--ignoreInvalid', action='store_true', help='Ignore invalid in thread')
 
-  parser.add_option('-r', '--rate', type='float', dest='plotSizeRate', default=1.5, help='Chart size rate.')
+  parser.add_argument('-r', '--rate', type=float, dest='plotSizeRate', default=1.5, help='Chart size rate.')
 
-  parser.add_option('--mask', dest='useMask', default='', help='mask certain data. Ex \'metric_nus*,metric_supply*\'. Will remove data collection label start with \'metric_nus and metric_supply\'')
+  parser.add_argument('--mask', dest='useMask', default='', help='mask certain data. Ex \'metric_nus*,metric_supply*\'. Will remove data collection label start with \'metric_nus and metric_supply\'')
 
-  parser.add_option('--aucSelect', dest='aucSelect', action='store_true', help='Select top n=selectLimit roc curve by roc AUC')
-  parser.add_option('--selectLimit', dest='selectLimit', default=0, type='int', help='Select top n model')
+  parser.add_argument('--aucSelect', dest='aucSelect', action='store_true', help='Select top n=selectLimit roc curve by roc AUC')
+  parser.add_argument('--selectLimit', dest='selectLimit', default=0, type=int, help='Select top n model')
 
-  (options,args) = parser.parse_args()
-  if len(args) < 1:
-    print('Input format: CSV by --delimiter: len(rocord)==4. Ex: modelId, weight, score, label')
-    parser.print_help()
-    exit(1)
-
-  print('Options:', options)
+  global args
+  args = parser.parse_args()
   print('Args:', args)
-  roc(args[0], options.phrase)
+  roc()
 
 if __name__ == '__main__':
     main()
